
.onLoad <- function(libname, pkgname) {
  require(lattice)
  require(grid)
  require(deSolve)
  require(neldermead)
  require(utils)
}